@@ -1,5 +1,5 @@
 smooth.pos <- function(argvals, y, WfdParobj, wtvec=rep(1,n), conv=1e-4,
-                       iterlim=50, dbglev=1) {
+                       iterlim=50, dbglev=1, returnMatrix=FALSE) {
 #  Smooths the relationship of Y to ARGVALS using weights in WTVEC by fitting a
 #     positive function of the form
 #                      f(x) = exp W(x)
@@ -11,61 +11,64 @@ smooth.pos <- function(argvals, y, WfdParobj, wtvec=rep(1,n), conv=1e-4,
 #  where L is a linear differential operator defined in argument Lfdobj,
 #  and w_i is a positive weight applied to the observation.
 #  The function W(x) is expanded by the basis in functional data object
-#    Wfdobj.   
+#    Wfdobj.
 
 #  Arguments:
-#  ARGVALS ...  Argument value array of length N, where N is the number of 
+#  ARGVALS ...  Argument value array of length N, where N is the number of
 #               observed curve values for each curve.  It is assumed that
 #               that these argument values are common to all observed
-#               curves.  If this is not the case, you will need to 
+#               curves.  If this is not the case, you will need to
 #               run this function inside one or more loops, smoothing
 #               each curve separately.
 #  Y       ...  Function value array (the values to be fit).
-#               If the functional data are univariate, this array will be 
+#               If the functional data are univariate, this array will be
 #               an N by NCURVE matrix, where N is the number of observed
 #               curve values for each curve and NCURVE is the number of
 #               curves observed.
-#               If the functional data are muliivariate, this array will be 
+#               If the functional data are muliivariate, this array will be
 #               an N by NCURVE by NVAR matrix, where NVAR the number of
 #               functions observed per case.  For example, for the gait
 #               data, NVAR = 2, since we observe knee and hip angles.
-#  WFDPAROBJ... A functional parameter or fdPar object.  This object 
+#  WFDPAROBJ... A functional parameter or fdPar object.  This object
 #               contains the specifications for the functional data
 #               object to be estimated by smoothing the data.  See
 #               comment lines in function fdPar for details.
 #               The functional data object WFD in WFDPAROBJ is used
 #               to initialize the optimization process.
-#               Its coefficient array contains the starting values for 
+#               Its coefficient array contains the starting values for
 #               the iterative minimization of mean squared error.
 #  WTVEC   ...  a vector of weights, a vector of N one's by default.
 #  CONV    ...  convergence criterion, 0.0001 by default
 #  ITERLIM ...  maximum number of iterations, 50 by default.
 #  DBGLEV  ...  Controls the level of output on each iteration.  If 0,
-#               no output, if 1, output at each iteration, if higher, 
+#               no output, if 1, output at each iteration, if higher,
 #               output at each line search iteration. 1 by default.
+#  RETURNMATRIX ... If False, a matrix in sparse storage model can be returned
+#               from a call to function BsplineS.  See this function for
+#               enabling this option.
 
 #  Returns are:
-#  WFD     ...  Functional data object for W. 
+#  WFD     ...  Functional data object for W.
 #               Its coefficient matrix an N by NCURVE (by NVAR) matrix
 #               (or array), depending on whether the functional
 #               observations are univariate or multivariate.
-#  FLIST ... A list object or a vector of list objects, one for 
+#  FLIST ... A list object or a vector of list objects, one for
 #            each curve (and each variable if functions are multivariate).
 #            Each list object has slots:
-#                 f    ... The sum of squared errors   
-#                 grad ... The gradient  
-#                 norm ... The norm of the gradient  
+#                 f    ... The sum of squared errors
+#                 grad ... The gradient
+#                 norm ... The norm of the gradient
 #  When multiple curves and variables are analyzed, the lists containing
 #  FLIST objects are indexed linear with curves varying inside
 #  variables.
 
-# last modified 21 September 2008 by Jim Ramsay
-# previously modified 3 January 2008 by Jim Ramsay  
+#  Last modified 9 May 2012  by Jim Ramsay
+
 
 #  check ARGVALS
 
 argvals <- argcheck(argvals)
-n       <- length(argvals)         
+n       <- length(argvals)
 onesobs <- matrix(1,n,1)
 
 #  at least two points are necessary for monotone smoothing
@@ -204,7 +207,7 @@ for (ivar in 1:nvar) {
       gvec        <- gvec0
       dbgwrd      <- dbglev > 1
 
-	if (iterlim == 0) {      
+	if (iterlim == 0) {
             cat("\n")
       } else {
 	for (iter in 1:iterlim) {
@@ -326,27 +329,27 @@ for (ivar in 1:nvar) {
       }
 
       #  save coefficients in arrays COEF and BETA
-        
+
       if (ndim == 2) {
         coef[,icurve] = cveci
       } else {
         coef[,icurve,ivar] = cveci
       }
-        
-      #  save Flisti 
-        
+
+      #  save Flisti
+
       if (ncurve == 1 && nvar == 1) {
         Flist = Flisti
       } else {
         Flist[[(ivar-1)*ncurve+icurve]] = Flisti
       }
-        
+
     }
   }
 
   Wfdobj = fd(coef, basisobj)
 
-  posFd <- list("Wfdobj"=Wfdobj, "Flist"=Flist, 
+  posFd <- list("Wfdobj"=Wfdobj, "Flist"=Flist,
                 "argvals"=argvals, "y"=y)
   class(posFd) <- 'posfd'
 
@@ -355,12 +358,13 @@ for (ivar in 1:nvar) {
 
 #  ---------------------------------------------------------------
 
-PENSSEfun <- function(argvals, yi, basisobj, cveci, Kmat, wtvec) {
+PENSSEfun <- function(argvals, yi, basisobj, cveci, Kmat, wtvec, 
+                      returnMatrix=FALSE) {
 	#  Computes the log likelihood and its derivative with
 	#    respect to the coefficients in CVEC
 	N       <- length(argvals)
 	nbasis  <- basisobj$nbasis
-	phimat  <- getbasismatrix(argvals, basisobj)
+	phimat  <- getbasismatrix(argvals, basisobj, 0, returnMatrix)
 	Wvec    <- phimat %*% cveci
 	EWvec   <- exp(Wvec)
 	res     <- yi - EWvec
@@ -371,11 +375,12 @@ PENSSEfun <- function(argvals, yi, basisobj, cveci, Kmat, wtvec) {
 
 #  ---------------------------------------------------------------
 
-PENSSEhess <- function(argvals, yi, basisobj, cveci, Kmat, wtvec) {
+PENSSEhess <- function(argvals, yi, basisobj, cveci, Kmat, wtvec, 
+                       returnMatrix=FALSE) {
 	#  Computes the expected Hessian
    	n       <- length(argvals)
    	nbasis  <- basisobj$nbasis
-   	phimat  <- getbasismatrix(argvals, basisobj)
+   	phimat  <- getbasismatrix(argvals, basisobj, 0, returnMatrix)
 	Wvec    <- phimat %*% cveci
 	EWvec   <- exp(Wvec)
 	res     <- yi - EWvec
